@@ -4,7 +4,7 @@ package Mail::AuthenticationResults::Header;
 require 5.008;
 use strict;
 use warnings;
-our $VERSION = '1.20180923'; # VERSION
+our $VERSION = '2.20210112'; # VERSION
 use Carp;
 
 use Mail::AuthenticationResults::Header::AuthServID;
@@ -174,6 +174,22 @@ sub add_child {
     return $self->SUPER::add_child( $child );
 }
 
+sub _as_hashref {
+    my ( $self ) = @_;
+
+    my $type = lc ref $self;
+    $type =~ s/^(.*::)//;
+    my $hashref = { 'type' => $type };
+
+    $hashref->{'key'} = $self->key() if $self->_HAS_KEY();
+    $hashref->{'authserv_id'} = $self->value()->_as_hashref() if $self->value();
+    if ( $self->_HAS_CHILDREN() ) {
+        my @children = map { $_->_as_hashref() } @{ $self->children() };
+        $hashref->{'children'} = \@children;
+    }
+    return $hashref;
+}
+
 sub as_string {
     my ( $self ) = @_;
     my $header = Mail::AuthenticationResults::FoldableHeader->new();
@@ -230,7 +246,7 @@ Mail::AuthenticationResults::Header - Class modelling the Entire Authentication
 
 =head1 VERSION
 
-version 1.20180923
+version 2.20210112
 
 =head1 DESCRIPTION
 
@@ -304,7 +320,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Marc Bradshaw.
+This software is copyright (c) 2020 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
