@@ -4,7 +4,7 @@ package Mail::AuthenticationResults::Header::Base;
 require 5.008;
 use strict;
 use warnings;
-our $VERSION = '1.20200108'; # VERSION
+our $VERSION = '2.20210112'; # VERSION
 use Scalar::Util qw{ weaken refaddr };
 use JSON;
 use Carp;
@@ -325,6 +325,7 @@ sub search {
     }
 
     if ( exists( $search->{ 'value' } ) ) {
+        $search->{ 'value' } = '' if ! defined $search->{ 'value' };
         if ( $self->_HAS_VALUE() ) {
             if ( ref $search->{ 'value' } eq 'Regexp' && $self->value() =~ m/$search->{'value'}/ ) {
                 $match = $match && 1;
@@ -414,42 +415,66 @@ Mail::AuthenticationResults::Header::Base - Base class for modelling parts of th
 
 =head1 VERSION
 
-version 1.20200108
+version 2.20210112
 
 =head1 DESCRIPTION
 
 Set of classes representing the various parts and sub parts of Authentication Results Headers.
 
+=over
+
+=item *
+
 L<Mail::AuthenticationResults::Header> represents a complete Authentication Results Header set
+
+=item * 
+
 L<Mail::AuthenticationResults::Header::AuthServID> represents the AuthServID part of the set
+
+=item * 
+
 L<Mail::AuthenticationResults::Header::Comment> represents a comment
+
+=item * 
+
 L<Mail::AuthenticationResults::Header::Entry> represents a main entry
+
+=item * 
+
 L<Mail::AuthenticationResults::Header::Group> represents a group of parts, typically as a search result
+
+=item * 
+
 L<Mail::AuthenticationResults::Header::SubEntry> represents a sub entry part
+
+=item * 
+
 L<Mail::AuthenticationResults::Header::Version> represents a version part
 
-Header
-    AuthServID
-        Version
-        Comment
-        SubEntry
-    Entry
-        Comment
-    Entry
-        Comment
+=back
+
+    Header
+        AuthServID
+            Version
+            Comment
+            SubEntry
+        Entry
+            Comment
+        Entry
+            Comment
+            SubEntry
+                Comment
+        Entry
+            SubEntry
+            SubEntry
+
+    Group
+        Entry
+            Comment
         SubEntry
             Comment
-    Entry
-        SubEntry
-        SubEntry
-
-Group
-    Entry
-        Comment
-    SubEntry
-        Comment
-    Entry
-        SubEntry
+        Entry
+            SubEntry
 
 =head1 METHODS
 
@@ -582,7 +607,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Marc Bradshaw.
+This software is copyright (c) 2020 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
